Date: 08 20, 2001 3:37:51 PM

# Closing Analyzers

To close an analyzer:

- From the File menu, select Close Analyzer. If the analyzer has been modified, you will be prompted to save the analyzer before closing.

Tip: You can also close the currently loaded analyzer by selecting Open Analyzer, navigating to another analyzer project and opening the .ana file. You can also close an analyzer by selecting an analyzer from the drop-down list under Recent Analyzers.

##